==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/zh-CN/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>信息</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>设置</strong> 和配置',
  '<strong>User</strong> administration' => '<strong>用户</strong> 管理',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '接受用户: <strong>{displayName}</strong>',
  'Account' => '帐号',
  'Account Request for \'{displayName}\' has been approved.' => '\'{displayName}\' 的账户请求已被通过。',
  'Account Request for \'{displayName}\' has been declined.' => '\'{displayName}\' 的账户请求已被拒绝。',
  'Actions' => '动作',
  'Active users' => '',
  'Add Groups...' => '增加组...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => '增加新类',
  'Add new field' => '增加新域',
  'Add new group' => '增加新的分组',
  'Add new members...' => '增加新的成员...',
  'Add new user' => '增加新用户',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => '允许',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => '允许未验证的用户（访客）有限访问',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => '取消',
  'Click here to review' => '点击这里查看',
  'Confirm user deletion' => '',
  'Could not load category.' => '不能加载到类',
  'Create new group' => '创建新组',
  'Create new profile category' => '创建新的属性分类',
  'Create new profile field' => '创建新的属性域',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => '拒绝并删除用户: <strong>{displayName}</strong>',
  'Default' => '默认',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => '默认用户闲置超时自动注销（秒，可选）',
  'Default user profile visibility' => '默认用户属性可见性',
  'Delete' => '删除',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => '失效',
  'Disabled' => '生效',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => '编辑属性分类',
  'Edit profile field' => '编辑属性域',
  'Edit user: {name}' => '编辑用户：{name}',
  'Enable' => '生效',
  'Enable individual profile permissions' => '',
  'Enabled' => '失效',
  'Group Manager' => '组管理',
  'Group not found!' => '组未找到',
  'Group user not found!' => '用户组没有找到！',
  'Groups' => '组',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => '在这里您可以创建或编辑属性的分类和域（字段）',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => '',
  'Last login' => '最后登录',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '管理分组: {groupName}',
  'Manage groups' => '管理组',
  'Manage profile attributes' => '管理属性的属性值',
  'Member since' => '',
  'Members' => '成员',
  'Members can invite external users by email' => '会员可以通过电子邮件邀请新用户',
  'Message' => '消息',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '最小值为20秒。如果没有设置，会话将会在1400秒（24分钟）无活动后超时（默认会话超时）',
  'New approval requests' => '新批准请求',
  'New users can register' => '任何人都能注册',
  'No' => '不',
  'No value found!' => '没有发现值',
  'One or more user needs your approval as group admin.' => '一个或多个用户申请你的批准',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '仅适用于非授权用户的有限访问启用时。只影响新用户。',
  'Overview' => '概览',
  'Password' => '密码',
  'Pending approvals' => '待审核',
  'Pending user approvals' => '待审核用户',
  'Permanently delete' => '',
  'Permissions' => '权限',
  'Profile Permissions' => '',
  'Profiles' => '属性',
  'Remove from group' => '从分组移除',
  'Require group admin approval after registration' => '注册后组管理员审批',
  'Resend invitation email' => '',
  'Save' => '保存',
  'Search by name, email or id.' => '',
  'Select Groups' => '选择组',
  'Send & save' => '发送并保存',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => '发送邀请',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => '设置',
  'Show group selection at registration' => '',
  'Subject' => '主题',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '下面的列表包含等待审核的所有注册用户。',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '此概览包括所有注册用户列表信息，包括查看，编辑，删除操作。',
  'This user owns no spaces.' => '',
  'Unapproved' => '未批准',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '用户已经是这个组的成员了。',
  'User not found!' => '未找到用户',
  'Users' => '用户管理',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '用户可以被分配给不同的组（如团队，部门等）与特定的标准空间，组管理人员和权限。',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '仅对成员可见',
  'Visible for members+guests' => '对成员或游客都可见',
  'Yes' => '好的',
  'You can only delete empty categories!' => '你只能删除空类',
  'You cannot delete yourself!' => '你不能删除自己',
  'never' => '从不',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/zh-CN/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>信息</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>设置</strong> 和配置',
  '<strong>User</strong> administration' => '<strong>用户</strong> 管理',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '接受用户: <strong>{displayName}</strong>',
  'Account' => '帐号',
  'Account Request for \'{displayName}\' has been approved.' => '\'{displayName}\' 的账户请求已被通过。',
  'Account Request for \'{displayName}\' has been declined.' => '\'{displayName}\' 的账户请求已被拒绝。',
  'Actions' => '动作',
  'Active users' => '',
  'Add Groups...' => '增加组...',
  'Add new category' => '增加新类',
  'Add new field' => '增加新域',
  'Add new group' => '增加新的分组',
  'Add new members...' => '增加新的成员...',
  'Add new user' => '增加新用户',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => '允许',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => '允许未验证的用户（访客）有限访问',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => '取消',
  'Click here to review' => '点击这里查看',
  'Confirm user deletion' => '',
  'Could not load category.' => '不能加载到类',
  'Create new group' => '创建新组',
  'Create new profile category' => '创建新的属性分类',
  'Create new profile field' => '创建新的属性域',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => '拒绝并删除用户: <strong>{displayName}</strong>',
  'Default' => '默认',
  'Default Profile Permissions' => '',
  'Default Sorting' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => '默认用户闲置超时自动注销（秒，可选）',
  'Default user profile visibility' => '默认用户属性可见性',
  'Delete' => '删除',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => '失效',
  'Disabled' => '生效',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => '编辑属性分类',
  'Edit profile field' => '编辑属性域',
  'Edit user: {name}' => '编辑用户：{name}',
  'Enable' => '生效',
  'Enable individual profile permissions' => '',
  'Enabled' => '失效',
  'First name' => '姓',
  'Group Manager' => '组管理',
  'Group not found!' => '组未找到',
  'Group user not found!' => '用户组没有找到！',
  'Groups' => '组',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => '在这里您可以创建或编辑属性的分类和域（字段）',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => '',
  'Last login' => '最后登录',
  'Last name' => '名',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '管理分组: {groupName}',
  'Manage groups' => '管理组',
  'Manage profile attributes' => '管理属性的属性值',
  'Member since' => '',
  'Members' => '成员',
  'Members can invite external users by email' => '会员可以通过电子邮件邀请新用户',
  'Message' => '消息',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '最小值为20秒。如果没有设置，会话将会在1400秒（24分钟）无活动后超时（默认会话超时）',
  'New approval requests' => '新批准请求',
  'New users can register' => '任何人都能注册',
  'No' => '不',
  'No value found!' => '没有发现值',
  'None' => '',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => '一个或多个用户申请你的批准',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '仅适用于非授权用户的有限访问启用时。只影响新用户。',
  'Overview' => '概览',
  'Password' => '密码',
  'Pending approvals' => '待审核',
  'Pending user approvals' => '待审核用户',
  'People' => '',
  'Permanently delete' => '',
  'Permissions' => '权限',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => '属性',
  'Protected' => '',
  'Protected group can not be deleted!' => '',
  'Remove from group' => '从分组移除',
  'Require group admin approval after registration' => '注册后组管理员审批',
  'Resend invitation email' => '',
  'Save' => '保存',
  'Search by name, email or id.' => '',
  'Select Groups' => '选择组',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => '发送并拒绝',
  'Send & save' => '发送并保存',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => '发送邀请',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => '设置',
  'Show group selection at registration' => '',
  'Subject' => '主题',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '下面的列表包含等待审核的所有注册用户。',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '此概览包括所有注册用户列表信息，包括查看，编辑，删除操作。',
  'This user owns no spaces.' => '',
  'Unapproved' => '未批准',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '用户已经是这个组的成员了。',
  'User not found!' => '未找到用户',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '用户可以被分配给不同的组（如团队，部门等）与特定的标准空间，组管理人员和权限。',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '仅对成员可见',
  'Visible for members+guests' => '对成员或游客都可见',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => '好的',
  'You can only delete empty categories!' => '你只能删除空类',
  'You cannot delete yourself!' => '你不能删除自己',
  'never' => '从不',
);
